# Komunikacni modul pro komunikaci s uzivatelem a ziskani vstupu
# zde se nachazi metody pro ziskani vstupu od uzivatele
#
# Autor: Miloš Barborka
# Verze: 1.0

from Vysvetlovani.vysvetlovaci_modul import *


def beh_vypisu_zacatek():
    """
    Ptani se na pocet nadob od uzivatele
    :return: seznam nadob
    """
    vypis_hlavicky()
    while True:
        try:
            # Vstup od uzivatele
            pocet_nadob = int(input("Zadejte pocet nadob (2 az 4): "))

            # Overeni, zda je vstup v pozadovanem rozsahu
            if pocet_nadob in [2, 3, 4]:
                break
            else:
                print("Pocet nadob musi byt cislo mezi 2 a 4.")
        except ValueError:
            print("Chyba: Zadejte prosim pouze cislo (2, 3 nebo 4).")

    # Zpracovani nadob
    nadoby = otazky_na_nadoby(pocet_nadob)
    print("--------------------------------------------------------------------------------------------------------")

    return nadoby


def otazky_na_nadoby(pocet_nadob):
    """
    Slouzi na ptani se otezek od uzivatele.
    :param pocet_nadob: pocet nadob
    :return: seznam nadob
    """
    parametr_maximalni = -1
    parametr_ostatni = -2
    nadoby = {}
    for i in range(pocet_nadob):
        print(f"\nNadoba cislo {i + 1}")

        ml_maximalne = over_vstup(f"Kolik ml maximalne pojme nadoba cislo {i + 1}? ", parametr_maximalni)
        ml_naplneno = over_vstup(f"Kolik ml je v nadobe cislo {i + 1}? ", parametr_ostatni)

        while ml_naplneno > ml_maximalne:
            print("Zadali jste vyssi naplneni nez je mozne naplnit nadobu.")
            ml_naplneno = over_vstup(f"Kolik ml je v nadobe cislo {i + 1}? ", parametr_ostatni)

        ml_koncovy_stav = over_vstup(f"Kolik ml chcete mit na konci v nadobe cislo {i + 1}? ", parametr_ostatni)

        while ml_koncovy_stav > ml_maximalne:
            print("Zadali jste vyssi naplneni nez je mozne naplnit nadobu.")
            ml_koncovy_stav = over_vstup(f"Kolik ml chcete mit na konci v nadobe cislo {i + 1}? ", parametr_ostatni)

        nadoby[i] = [ml_naplneno, ml_maximalne, ml_koncovy_stav]
    return nadoby


def over_vstup(zprava, ml_maximalni):
    """
    Overeni vstupu oduzivatele
    :param zprava: vstup od uzivatele
    :param ml_maximalni: zda se ptame na maximalni objem nadoby
    :return: None
    """
    while True:
        try:
            hodnota = int(input(zprava))
            if ml_maximalni == -1:
                if hodnota > 0:
                    return hodnota
                else:
                    print("Zadejte cislo vetsi nez nula.")

            if ml_maximalni == -2:
                if hodnota >= 0:
                    return hodnota
                else:
                    print("Zadejte cislo vetsi nez nula.")
        except ValueError:
            print("Neplatny vstup! Zadejte cele cislo.")


def pokracovani():
    """
    Pouze pro pokracovani v behu programu
    :return: False, kdyz nechceme v behu programu pokracovat
    """
    odpoved = input("Chcete pokracovat s dalsimi nadobami? ANO/NE\n").strip().upper()
    if odpoved == "NE":
        print("Konec programu.")
        return False
    return True
