"""
Author: Miroslav Bártík
Name of the program: Lloydova 15
Version: 1.0
date: 18.11.2024
description: This module serves as interpreter of the achieved results, so the user can easily understand them
"""

from K_base import Puzzle


def print_solution_path(solution_path, puzzle: Puzzle):
    """
    Prints the step-by-step solution to the puzzle.

    :param solution_path: List of moves (e.g., "up", "down") required to solve the puzzle.
    :param puzzle: The initial state of the puzzle as a Puzzle object.
    """
    # Create a copy of the puzzle to preserve its initial state
    current_puzzle = puzzle.copy()

    # Iterate through the solution path and display each move
    for i, move in enumerate(solution_path):
        print(f"Move #{i + 1}: {move}")  # Print the move number and the move direction
        print_grid(current_puzzle.grid)  # Display the current state of the grid
        current_puzzle.move(move)  # Apply the move to the copied puzzle

    # Final state after all moves
    print("Solved puzzle!")
    print_grid(current_puzzle.grid)


def print_grid(grid):
    """
    Prints the puzzle grid with formatted rows and highlights the empty tile as "XX".

    :param grid: 2D list representing the puzzle grid.
    """
    for row in grid:
        # Format each tile, replacing 0 (empty tile) with "XX", and print in yellow
        print("\033[93m" + " ".join(f"{'XX' if x == 0 else x:2}" for x in row) + "\033[0m")
    print()


def print_init_grid(grid):
    """
    Prints the initial state of the puzzle grid.

    :param grid: 2D list representing the puzzle grid.
    """
    print("OK, so this is the starting state of the grid:\n")
    print_grid(grid)  # Delegate grid printing to the `print_grid` function


def print_statistics(move_count: int, expanded_nodes: int, time: float):
    """
    Prints the statistics of the puzzle-solving process.

    :param move_count: Number of moves required to solve the puzzle.
    :param expanded_nodes: Number of nodes expanded during the search.
    :param time: Time taken to solve the puzzle (in seconds).
    """
    print("\033[94m\n--- Puzzle Solving Statistics ---\033[0m")  # Header in blue
    print(f"Moves required to solve: \033[93m{move_count}\033[0m")  # Number of moves in yellow
    print(f"Nodes expanded: \033[93m{expanded_nodes}\033[0m")  # Nodes expanded in yellow
    print(f"Time of solving[s]: \033[93m{time:.4f}\033[0m")  # Time in yellow with 4 decimal places
    print("\033[94m---------------------------------\033[0m")  # Footer in blue


def print_im_computing():
    """
    Lets the user know that the application is computing
    """
    print("I'm computing...", end="")

def print_finished():
    """
    Lets the user know that the application finished computing
    """
    print("\rSolution found!\n\n")


