"""
This class @Aircraft represents a plane in the airport knowledge-based system.
It includes attributes for the aircraft's name, associated gates,
and whether it has free parking privileges.

Author:
    Václav Hajšman (hajsman2@student-zcu.cz)
Date:
    7.11.2024
Version:
    1.0
"""
from DataStructures.Gate import Gate


class Aircraft:
    """
    Represents an aircraft in the airport system.

    Attributes:
        name (str): The name of the aircraft.
        gates (list[Gate]): A list of Gate objects assigned to the aircraft.
        freePark (bool): Indicates if the aircraft has free parking privileges.
    """

    def __init__(self, name: str, gates: list[Gate], freePark: bool):
        """
        Initializes an Aircraft object.

        Parameters:
            name (str): The name of the aircraft.
            gates (list[Gate]): A list of Gate objects assigned to the aircraft.
            freePark (bool): Whether the aircraft has free parking privileges.
        """
        self.name = name
        self.gates = gates
        self.freePark = freePark

    def __str__(self) -> str:
        """
        Returns a string representation of the Aircraft object.

        The string includes the aircraft's name, the list of associated gates,
        and whether free parking is available.

        Returns:
            str: A formatted string describing the aircraft.
        """
        gates_str = ", ".join(str(gate) for gate in self.gates)
        return (f"Letadlo: {self.name}, "
                f"Brány: [{gates_str}], "
                f"Volné parkování: {'Ano' if self.freePark else 'Ne'}")
