"""
This class @Airport represents an airport in the airport knowledge-based system.
It includes attributes for the list of gates and the count of free parking spaces.

Author:
    Václav Hajšman (hajsman2@student-zcu.cz)
Date:
    7.11.2024
Version:
    1.0
"""

from DataStructures.Gate import Gate


class Airport:
    """
    Represents an airport in the system.

    Attributes:
        gates (list[Gate]): A list of Gate objects available at the airport.
        freeParkCount (int): The number of free parking spaces at the airport.
    """

    def __init__(self, gates: list[Gate], freeParkCount: int):
        """
        Initializes an Airport object.

        Parameters:
            gates (list[Gate]): A list of Gate objects available at the airport.
            freeParkCount (int): The number of free parking spaces available.
        """
        self.gates = gates
        self.freeParkCount = freeParkCount

    def __str__(self) -> str:
        """
        Returns a string representation of the Airport object.

        The string includes the list of gates and the number of free parking spaces.

        Returns:
            str: A formatted string describing the airport.
        """
        gates_str = ", ".join(str(gate) for gate in self.gates)
        return (f"Aerodrom, Brány: [{gates_str}], "
                f"Počet volných parkovacích míst: {self.freeParkCount}")
