# -*- coding: utf-8 -*-
"""
Rohlik Store Module
Author: Martin Riedl
Email: marty69@students.zcu.cz
Date: 13.12.2024
Version: 1.0

This module defines the Rohlik online store data used in the shopping recommendation system. The
`store` dictionary contains information about the store's assortment, opening hours, and distance.

Attributes:
    store (dict): A dictionary containing Rohlik's store data, including assortment, opening hours, and distance.
"""

store = {
    "name": "Rohlik",
    "assortment": {
        "tofu": {"price": 165, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "cibule": {"price": 125, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "paprika": {"price": 129, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "orechy": {"price": 165, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "arasidy": {"price": 140, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "kari_pasta": {"price": 138, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "kokosove_mleko": {"price": 150, "mnozstvi": 400, "jednotky": "ml", "na_sklade": 999},
        "tamari": {"price": 158, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 999},
        "olej": {"price": 142, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "cukr": {"price": 126, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "sul": {"price": 122, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "cesnek": {"price": 124, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "chilli": {"price": 126, "mnozstvi": 10, "jednotky": "g", "na_sklade": 999},
        "skrob": {"price": 128, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "ryze": {"price": 131, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "zelenina_mix": {"price": 141, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "voda": {"price": 132, "mnozstvi": 10, "jednotky": "l", "na_sklade": 999},
        "dzus_pomerancovy": {"price": 155, "mnozstvi": 2, "jednotky": "l", "na_sklade": 999},
        "dzus_jablecny": {"price": 150, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 999},
        "cola": {"price": 140, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "sprite": {"price": 145, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 999},
        "tonic": {"price": 138, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "pivo": {"price": 180, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 999},
        "vino_bile": {"price": 240, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "vino_cervene": {"price": 250, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "whisky": {"price": 620, "mnozstvi": 0.7, "jednotky": "l", "na_sklade": 999},
        "rum": {"price": 520, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "vodka": {"price": 420, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "kava": {"price": 210, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "caj_cerny": {"price": 160, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "caj_zeleny": {"price": 170, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "energeticky_napoj": {"price": 145, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 999},
        "mliko": {"price": 140, "mnozstvi": 2, "jednotky": "l", "na_sklade": 999},
        "smetana_do_kavy": {"price": 135, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 999},
        "mandlove_mleko": {"price": 155, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "sojove_mleko": {"price": 150, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "kakao": {"price": 145, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "kokosova_voda": {"price": 160, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "mineralka": {"price": 135, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 999},
        "mrazeny_hrasek": {"price": 145, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "mrazeny_spenat": {"price": 140, "mnozstvi": 400, "jednotky": "g", "na_sklade": 999},
        "mrazeny_brokolice": {"price": 155, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "zmrzlina_vanilkova": {"price": 170, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "zmrzlina_cokoladova": {"price": 165, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 999},
        "mouka_hladka": {"price": 132, "mnozstvi": 2000, "jednotky": "g", "na_sklade": 999},
        "mouka_polohruba": {"price": 132, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "mouka_ryzova": {"price": 140, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "testoviny": {"price": 145, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "kuskus": {"price": 138, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "bulgur": {"price": 138, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "olej_slunecnicovy": {"price": 160, "mnozstvi": 1.0, "jednotky": "l", "na_sklade": 999},
        "olej_olivovy": {"price": 180, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "olej_kokosovy": {"price": 220, "mnozstvi": 5.0, "jednotky": "l", "na_sklade": 999},
        "ghi": {"price": 240, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "sojova_omacka": {"price": 170, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "kecup": {"price": 150, "mnozstvi": 1.0, "jednotky": "l", "na_sklade": 999},
        "horcice": {"price": 145, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "med": {"price": 220, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "dzin": {"price": 320, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 999},
        "kakao_prasek": {"price": 150, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "cornflakes": {"price": 170, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "ovesne_vlocky": {"price": 160, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "mrazena_zelenina": {"price": 180, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "kroupy": {"price": 140, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "cizrna": {"price": 160, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "cocka": {"price": 150, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "fazole": {"price": 170, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "konzervovane_tunaky": {"price": 180, "mnozstvi": 5, "jednotky": "ks", "na_sklade": 999},
        "konzervovana_kukurice": {"price": 160, "mnozstvi": 3, "jednotky": "ks", "na_sklade": 999},
        "konzervovane_fazole": {"price": 165, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 999},
        "cokolada_horka": {"price": 190, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "cokolada_mlecna": {"price": 180, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "susene_jahody": {"price": 240, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "susene_svestky": {"price": 210, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "rozinky": {"price": 170, "mnozstvi": 150, "jednotky": "g", "na_sklade": 999},
        "suchary": {"price": 155, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "krekry": {"price": 160, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "chipsy": {"price": 165, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "sul": {"price": 125, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "pepr_mlety": {"price": 145, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "pepr_cely": {"price": 150, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "paprika_sladka": {"price": 140, "mnozstvi": 150, "jednotky": "g", "na_sklade": 999},
        "paprika_stiplava": {"price": 142, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "chilli_prasek": {"price": 155, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "kurkuma": {"price": 138, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "kari": {"price": 145, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "oregano": {"price": 135, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "majoranka": {"price": 135, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "tymian": {"price": 135, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "rozmaryn": {"price": 135, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "bazalka": {"price": 135, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "cesnek_suseny": {"price": 140, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "cibule_susena": {"price": 140, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "zazvor_mlety": {"price": 148, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "hrebicek": {"price": 160, "mnozstvi": 30, "jednotky": "g", "na_sklade": 999},
        "skorice_mleta": {"price": 142, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "skorice_cela": {"price": 145, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "bobkovy_list": {"price": 135, "mnozstvi": 20, "jednotky": "g", "na_sklade": 999},
        "novy_koreni": {"price": 138, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "vanilka_lusk": {"price": 270, "mnozstvi": 5, "jednotky": "ks", "na_sklade": 999},
        "vanilkovy_cukr": {"price": 130, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "smes_provensalske": {"price": 140, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "kari_pasta": {"price": 155, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "sojova_omacka": {"price": 145, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 999},
        "balzamovy_ocet": {"price": 165, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 999},
        "tabasco": {"price": 170, "mnozstvi": 0.06, "jednotky": "l", "na_sklade": 999},
        "wasabi": {"price": 180, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "mlety_kmin": {"price": 135, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "cely_kmin": {"price": 135, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "kureci_prsa": {"price": 210, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "kruti_prsa": {"price": 240, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "veprove_kotlety": {"price": 230, "mnozstvi": 400, "jednotky": "g", "na_sklade": 999},
        "hovezi_maso": {"price": 270, "mnozstvi": 600, "jednotky": "g", "na_sklade": 999},
        "rybi_filety": {"price": 250, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "slanina": {"price": 190, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "sunka": {"price": 180, "mnozstvi": 150, "jednotky": "g", "na_sklade": 999},
        "parky": {"price": 160, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 999},
        "vejce": {"price": 170, "mnozstvi": 12, "jednotky": "ks", "na_sklade": 999},
        "mleko": {"price": 140, "mnozstvi": 1.0, "jednotky": "l", "na_sklade": 999},
        "smetana": {"price": 145, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "jogurt": {"price": 135, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "mascarpone": {"price": 180, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "ricotta": {"price": 170, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "tvaroh": {"price": 150, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "syr_eidam": {"price": 160, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "parmazan": {"price": 220, "mnozstvi": 150, "jednotky": "g", "na_sklade": 999},
        "mozarella": {"price": 170, "mnozstvi": 125, "jednotky": "g", "na_sklade": 999},
        "zelenina_mix": {"price": 160, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "mrkev": {"price": 130, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 999},
        "celer": {"price": 135, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "paprika": {"price": 140, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 999},
        "rajcata": {"price": 150, "mnozstvi": 5, "jednotky": "ks", "na_sklade": 999},
        "okurka": {"price": 135, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "salat": {"price": 140, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "brokolice": {"price": 145, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "kvetak": {"price": 145, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "cibule": {"price": 130, "mnozstvi": 3, "jednotky": "ks", "na_sklade": 999},
        "cesnek": {"price": 140, "mnozstvi": 2, "jednotky": "hlavicky", "na_sklade": 999},
        "brambory": {"price": 135, "mnozstvi": 500, "jednotky": "ks", "na_sklade": 999},
        "jablka": {"price": 145, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 999},
        "hrusky": {"price": 140, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 999},
        "pomerance": {"price": 150, "mnozstvi": 3, "jednotky": "ks", "na_sklade": 999},
        "citron": {"price": 135, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 999},
        "limetky": {"price": 135, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 999},
        "kokosove_mleko": {"price": 160, "mnozstvi": 0.4, "jednotky": "l", "na_sklade": 999},
        "kecup": {"price": 140, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "horcice": {"price": 145, "mnozstvi": 0.3, "jednotky": "l", "na_sklade": 999},
        "sojova_omacka": {"price": 150, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 999},
        "vajecna_pasta": {"price": 170, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "maslo": {"price": 180, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "margarin": {"price": 170, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "dzem": {"price": 160, "mnozstvi": 400, "jednotky": "g", "na_sklade": 999},
        "med": {"price": 200, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "tatarka": {"price": 150, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 999},
        "majoneza": {"price": 155, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 999},
        "olivy": {"price": 170, "mnozstvi": 150, "jednotky": "g", "na_sklade": 999},
        "nakladane_okurky": {"price": 160, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "kapary": {"price": 180, "mnozstvi": 50, "jednotky": "g", "na_sklade": 999},
        "kysane_zeli": {"price": 150, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "slanina_platky": {"price": 200, "mnozstvi": 200, "jednotky": "g", "na_sklade": 999},
        "mrazeny_hrasek": {"price": 150, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "mrazeny_spenat": {"price": 145, "mnozstvi": 400, "jednotky": "g", "na_sklade": 999},
        "mrazeny_brokolice": {"price": 155, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "mrazene_rybi_filety": {"price": 210, "mnozstvi": 600, "jednotky": "g", "na_sklade": 999},
        "mrazeny_kureci_prsa": {"price": 240, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "mrazeny_kvetak": {"price": 160, "mnozstvi": 400, "jednotky": "g", "na_sklade": 999},
        "mrazeny_mrkev": {"price": 140, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "mrazene_jahody": {"price": 180, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "mrazene_maliny": {"price": 190, "mnozstvi": 400, "jednotky": "g", "na_sklade": 999},
        "mrazene_boruvky": {"price": 200, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "mrazene_svestky": {"price": 170, "mnozstvi": 400, "jednotky": "g", "na_sklade": 999},
        "zmrzlina_vanilkova": {"price": 220, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "zmrzlina_cokoladova": {"price": 200, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 999},
        "mrazene_lasagne": {"price": 240, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "mrazena_pizza": {"price": 270, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 999},
        "mrazeny_bramborovy_hranolky": {"price": 170, "mnozstvi": 750, "jednotky": "g", "na_sklade": 999},
        "mrazene_pirohy": {"price": 180, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "mrazene_maso": {"price": 320, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 999},
        "mrazene_chleba": {"price": 145, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 999},
        "mrazene_bulky": {"price": 160, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 999},
        "mrazene_rybi_prsty": {"price": 190, "mnozstvi": 300, "jednotky": "g", "na_sklade": 999},
        "mrazene_plody_mori": {"price": 240, "mnozstvi": 500, "jednotky": "g", "na_sklade": 999},
        "mrazene_gulase": {"price": 220, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 999},
        "mrazene_ravioli": {"price": 180, "mnozstvi": 400, "jednotky": "g", "na_sklade": 999},
        "mrazene_susenky": {"price": 170, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "voda": {"price": 130, "mnozstvi": 10, "jednotky": "l", "na_sklade": 999},
        "dzus_pomerancovy": {"price": 150, "mnozstvi": 2, "jednotky": "l", "na_sklade": 999},
        "dzus_jablecny": {"price": 145, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 999},
        "cola": {"price": 140, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "sprite": {"price": 140, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 999},
        "tonic": {"price": 135, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "pivo": {"price": 132, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 999},
        "vino_bile": {"price": 220, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "vino_cervene": {"price": 240, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "whisky": {"price": 620, "mnozstvi": 0.7, "jednotky": "l", "na_sklade": 999},
        "rum": {"price": 420, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "vodka": {"price": 320, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "liker": {"price": 270, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "kava": {"price": 200, "mnozstvi": 250, "jednotky": "g", "na_sklade": 999},
        "caj_cerny": {"price": 170, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "caj_zeleny": {"price": 170, "mnozstvi": 100, "jednotky": "g", "na_sklade": 999},
        "energeticky_napoj": {"price": 160, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 999},
        "mliko": {"price": 140, "mnozstvi": 2, "jednotky": "l", "na_sklade": 999},
        "smetana_do_kavy": {"price": 135, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 999},
        "mandlove_mleko": {"price": 155, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "sojove_mleko": {"price": 150, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "kakao": {"price": 145, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999},
        "ledovy_caj": {"price": 140, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 999},
        "kokosova_voda": {"price": 150, "mnozstvi": 1, "jednotky": "l", "na_sklade": 999},
        "mineralka": {"price": 135, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 999},
        "perlive_vino": {"price": 270, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 999},
        "domaci_sirup": {"price": 170, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 999}
    },
    "open_from": (0, 0),
    "open_to": (23, 59),
    "distance": 0.0
}