# -*- coding: utf-8 -*-
"""
Tesco Store Module
Author: Martin Riedl
Email: marty69@students.zcu.cz
Date: 13.12.2024
Version: 1.0

This module defines the Tesco store data used in the shopping recommendation system. The
`store` dictionary contains information about the store's assortment, opening hours, and distance.

Attributes:
    store (dict): A dictionary containing Tesco's store data, including assortment, opening hours, and distance.
"""

store = {
    "name": "Tesco",
    "assortment": {
        "tofu": {"price": 49, "mnozstvi": 250, "jednotky": "g", "na_sklade": 0},
        "cibule": {"price": 6, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 12},
        "paprika": {"price": 12, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 5},
        "orechy": {"price": 50, "mnozstvi": 100, "jednotky": "g", "na_sklade": 3},
        "arasidy": {"price": 22, "mnozstvi": 100, "jednotky": "g", "na_sklade": 0},
        "kari_pasta": {"price": 20, "mnozstvi": 50, "jednotky": "g", "na_sklade": 7},
        "kokosove_mleko": {"price": 35, "mnozstvi": 400, "jednotky": "ml", "na_sklade": 4},
        "tamari": {"price": 40, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 3},
        "olej": {"price": 25, "mnozstvi": 1, "jednotky": "l", "na_sklade": 8},
        "cukr": {"price": 7, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 9},
        "sul": {"price": 3, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 8},
        "cesnek": {"price": 5, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 7},
        "chilli": {"price": 7, "mnozstvi": 10, "jednotky": "g", "na_sklade": 6},
        "skrob": {"price": 10, "mnozstvi": 500, "jednotky": "g", "na_sklade": 5},
        "ryze": {"price": 13, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 12},
        "zelenina_mix": {"price": 24, "mnozstvi": 500, "jednotky": "g", "na_sklade": 0},
        "kureci_prsa": {"price": 110, "mnozstvi": 500, "jednotky": "g", "na_sklade": 6},
        "voda": {"price": 15, "mnozstvi": 10, "jednotky": "l", "na_sklade": 40},
        "dzus_pomerancovy": {"price": 37, "mnozstvi": 2, "jednotky": "l", "na_sklade": 18},
        "dzus_jablecny": {"price": 32, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 10},
        "cola": {"price": 22, "mnozstvi": 1, "jednotky": "l", "na_sklade": 25},
        "sprite": {"price": 27, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 20},
        "tonic": {"price": 20, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 8},
        "pivo": {"price": 65, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 35},
        "vino_bile": {"price": 125, "mnozstvi": 1, "jednotky": "l", "na_sklade": 15},
        "vino_cervene": {"price": 135, "mnozstvi": 1, "jednotky": "l", "na_sklade": 10},
        "whisky": {"price": 520, "mnozstvi": 0.7, "jednotky": "l", "na_sklade": 4},
        "rum": {"price": 410, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 3},
        "vodka": {"price": 310, "mnozstvi": 1, "jednotky": "l", "na_sklade": 7},
        "kava": {"price": 95, "mnozstvi": 250, "jednotky": "g", "na_sklade": 10},
        "caj_cerny": {"price": 42, "mnozstvi": 100, "jednotky": "g", "na_sklade": 8},
        "caj_zeleny": {"price": 55, "mnozstvi": 100, "jednotky": "g", "na_sklade": 5},
        "energeticky_napoj": {"price": 27, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 25},
        "mliko": {"price": 22, "mnozstvi": 2, "jednotky": "l", "na_sklade": 18},
        "smetana_do_kavy": {"price": 17, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 8},
        "mandlove_mleko": {"price": 37, "mnozstvi": 1, "jednotky": "l", "na_sklade": 7},
        "sojove_mleko": {"price": 32, "mnozstvi": 1, "jednotky": "l", "na_sklade": 6},
        "kakao": {"price": 28, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 5},
        "kokosova_voda": {"price": 42, "mnozstvi": 1, "jednotky": "l", "na_sklade": 12},
        "mineralka": {"price": 17, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 25},
        "mrazeny_hrasek": {"price": 28, "mnozstvi": 500, "jednotky": "g", "na_sklade": 8},
        "mrazeny_spenat": {"price": 22, "mnozstvi": 400, "jednotky": "g", "na_sklade": 6},
        "mrazeny_brokolice": {"price": 38, "mnozstvi": 300, "jednotky": "g", "na_sklade": 2},
        "zmrzlina_vanilkova": {"price": 55, "mnozstvi": 1, "jednotky": "l", "na_sklade": 8},
        "zmrzlina_cokoladova": {"price": 50, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 6},
        "mouka_hladka": {"price": 15, "mnozstvi": 2000, "jednotky": "g", "na_sklade": 10},
        "mouka_polohruba": {"price": 14, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 20},
        "mouka_ryzova": {"price": 22, "mnozstvi": 500, "jednotky": "g", "na_sklade": 8},
        "testoviny": {"price": 28, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 40},
        "kuskus": {"price": 20, "mnozstvi": 500, "jednotky": "g", "na_sklade": 18},
        "bulgur": {"price": 21, "mnozstvi": 500, "jednotky": "g", "na_sklade": 10},
        "olej_slunecnicovy": {"price": 45, "mnozstvi": 1.0, "jednotky": "l", "na_sklade": 25},
        "olej_olivovy": {"price": 65, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 15},
        "olej_kokosovy": {"price": 105, "mnozstvi": 5.0, "jednotky": "l", "na_sklade": 8},
        "ghi": {"price": 125, "mnozstvi": 500, "jednotky": "g", "na_sklade": 3},
        "brambory": {"price": 28, "mnozstvi": 50, "jednotky": "ks", "na_sklade": 45},
        "sojova_omacka": {"price": 52, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 12},
        "kecup": {"price": 35, "mnozstvi": 1.0, "jednotky": "l", "na_sklade": 15},
        "horcice": {"price": 28, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 8},
        "med": {"price": 105, "mnozstvi": 500, "jednotky": "g", "na_sklade": 3},
        "dzin": {"price": 220, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 5},
        "kakao_prasek": {"price": 32, "mnozstvi": 200, "jednotky": "g", "na_sklade": 20},
        "cornflakes": {"price": 55, "mnozstvi": 500, "jednotky": "g", "na_sklade": 15},
        "ovesne_vlocky": {"price": 45, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 25},
        "mrazena_zelenina": {"price": 65, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 10},
        "kroupy": {"price": 22, "mnozstvi": 500, "jednotky": "g", "na_sklade": 5},
        "cizrna": {"price": 42, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 18},
        "cocka": {"price": 35, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 25},
        "fazole": {"price": 55, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 15},
        "konzervovane_tunaky": {"price": 65, "mnozstvi": 5, "jednotky": "ks", "na_sklade": 8},
        "konzervovana_kukurice": {"price": 45, "mnozstvi": 3, "jednotky": "ks", "na_sklade": 7},
        "konzervovane_fazole": {"price": 50, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 10},
        "cokolada_horka": {"price": 75, "mnozstvi": 200, "jednotky": "g", "na_sklade": 8},
        "cokolada_mlecna": {"price": 65, "mnozstvi": 200, "jednotky": "g", "na_sklade": 12},
        "susene_jahody": {"price": 130, "mnozstvi": 100, "jednotky": "g", "na_sklade": 3},
        "susene_svestky": {"price": 95, "mnozstvi": 200, "jednotky": "g", "na_sklade": 5},
        "rozinky": {"price": 55, "mnozstvi": 150, "jednotky": "g", "na_sklade": 8},
        "suchary": {"price": 38, "mnozstvi": 500, "jednotky": "g", "na_sklade": 15},
        "krekry": {"price": 45, "mnozstvi": 250, "jednotky": "g", "na_sklade": 10},
        "chipsy": {"price": 50, "mnozstvi": 300, "jednotky": "g", "na_sklade": 18},
        "sul": {"price": 6, "mnozstvi": 500, "jednotky": "g", "na_sklade": 40},
        "pepr_mlety": {"price": 28, "mnozstvi": 200, "jednotky": "g", "na_sklade": 15},
        "pepr_cely": {"price": 35, "mnozstvi": 100, "jednotky": "g", "na_sklade": 10},
        "paprika_sladka": {"price": 25, "mnozstvi": 150, "jednotky": "g", "na_sklade": 20},
        "paprika_stiplava": {"price": 27, "mnozstvi": 100, "jednotky": "g", "na_sklade": 15},
        "chilli_prasek": {"price": 40, "mnozstvi": 50, "jednotky": "g", "na_sklade": 8},
        "kurkuma": {"price": 20, "mnozstvi": 100, "jednotky": "g", "na_sklade": 25},
        "kari": {"price": 30, "mnozstvi": 200, "jednotky": "g", "na_sklade": 15},
        "oregano": {"price": 18, "mnozstvi": 50, "jednotky": "g", "na_sklade": 15},
        "majoranka": {"price": 18, "mnozstvi": 50, "jednotky": "g", "na_sklade": 20},
        "tymian": {"price": 18, "mnozstvi": 50, "jednotky": "g", "na_sklade": 15},
        "rozmaryn": {"price": 18, "mnozstvi": 50, "jednotky": "g", "na_sklade": 15},
        "bazalka": {"price": 18, "mnozstvi": 50, "jednotky": "g", "na_sklade": 20},
        "cesnek_suseny": {"price": 22, "mnozstvi": 100, "jednotky": "g", "na_sklade": 25},
        "cibule_susena": {"price": 22, "mnozstvi": 100, "jednotky": "g", "na_sklade": 25},
        "zazvor_mlety": {"price": 30, "mnozstvi": 50, "jednotky": "g", "na_sklade": 10},
        "hrebicek": {"price": 45, "mnozstvi": 30, "jednotky": "g", "na_sklade": 8},
        "skorice_mleta": {"price": 25, "mnozstvi": 100, "jednotky": "g", "na_sklade": 15},
        "skorice_cela": {"price": 28, "mnozstvi": 50, "jednotky": "g", "na_sklade": 10},
        "bobkovy_list": {"price": 18, "mnozstvi": 20, "jednotky": "g", "na_sklade": 20},
        "novy_koreni": {"price": 20, "mnozstvi": 50, "jednotky": "g", "na_sklade": 15},
        "vanilka_lusk": {"price": 160, "mnozstvi": 5, "jednotky": "ks", "na_sklade": 8},
        "vanilkovy_cukr": {"price": 12, "mnozstvi": 200, "jednotky": "g", "na_sklade": 25},
        "smes_provensalske": {"price": 22, "mnozstvi": 50, "jednotky": "g", "na_sklade": 15},
        "kari_pasta": {"price": 38, "mnozstvi": 100, "jednotky": "g", "na_sklade": 10},
        "sojova_omacka": {"price": 28, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 15},
        "balzamovy_ocet": {"price": 50, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 12},
        "tabasco": {"price": 55, "mnozstvi": 0.06, "jednotky": "l", "na_sklade": 8},
        "wasabi": {"price": 65, "mnozstvi": 50, "jednotky": "g", "na_sklade": 8},
        "mlety_kmin": {"price": 18, "mnozstvi": 100, "jednotky": "g", "na_sklade": 15},
        "cely_kmin": {"price": 18, "mnozstvi": 100, "jednotky": "g", "na_sklade": 20},
        "kruti_prsa": {"price": 125, "mnozstvi": 500, "jednotky": "g", "na_sklade": 10},
        "veprove_kotlety": {"price": 115, "mnozstvi": 400, "jednotky": "g", "na_sklade": 8},
        "hovezi_maso": {"price": 155, "mnozstvi": 600, "jednotky": "g", "na_sklade": 5},
        "rybi_filety": {"price": 135, "mnozstvi": 300, "jednotky": "g", "na_sklade": 8},
        "slanina": {"price": 75, "mnozstvi": 200, "jednotky": "g", "na_sklade": 12},
        "sunka": {"price": 65, "mnozstvi": 150, "jednotky": "g", "na_sklade": 15},
        "parky": {"price": 45, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 20},
        "vejce": {"price": 55, "mnozstvi": 12, "jednotky": "ks", "na_sklade": 25},
        "mleko": {"price": 20, "mnozstvi": 1.0, "jednotky": "l", "na_sklade": 50},
        "smetana": {"price": 25, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 30},
        "jogurt": {"price": 15, "mnozstvi": 500, "jednotky": "g", "na_sklade": 25},
        "mascarpone": {"price": 60, "mnozstvi": 250, "jednotky": "g", "na_sklade": 10},
        "ricotta": {"price": 50, "mnozstvi": 200, "jednotky": "g", "na_sklade": 15},
        "tvaroh": {"price": 30, "mnozstvi": 250, "jednotky": "g", "na_sklade": 20},
        "syr_eidam": {"price": 40, "mnozstvi": 300, "jednotky": "g", "na_sklade": 30},
        "parmazan": {"price": 100, "mnozstvi": 150, "jednotky": "g", "na_sklade": 15},
        "mozarella": {"price": 50, "mnozstvi": 125, "jednotky": "g", "na_sklade": 20},
        "zelenina_mix": {"price": 40, "mnozstvi": 500, "jednotky": "g", "na_sklade": 20},
        "mrkev": {"price": 10, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 40},
        "celer": {"price": 15, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 20},
        "paprika": {"price": 20, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 25},
        "rajcata": {"price": 30, "mnozstvi": 5, "jednotky": "ks", "na_sklade": 35},
        "okurka": {"price": 15, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 25},
        "salat": {"price": 20, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 15},
        "brokolice": {"price": 25, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 10},
        "kvetak": {"price": 25, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 10},
        "cibule": {"price": 10, "mnozstvi": 3, "jednotky": "ks", "na_sklade": 50},
        "cesnek": {"price": 20, "mnozstvi": 2, "jednotky": "hlavicky", "na_sklade": 20},
        "jablka": {"price": 25, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 30},
        "hrusky": {"price": 20, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 25},
        "pomerance": {"price": 30, "mnozstvi": 3, "jednotky": "ks", "na_sklade": 20},
        "citron": {"price": 15, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 15},
        "limetky": {"price": 15, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 15},
        "kokosove_mleko": {"price": 40, "mnozstvi": 0.4, "jednotky": "l", "na_sklade": 10},
        "kecup": {"price": 20, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 30},
        "horcice": {"price": 25, "mnozstvi": 0.3, "jednotky": "l", "na_sklade": 25},
        "sojova_omacka": {"price": 30, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 20},
        "vajecna_pasta": {"price": 50, "mnozstvi": 250, "jednotky": "g", "na_sklade": 15},
        "maslo": {"price": 60, "mnozstvi": 250, "jednotky": "g", "na_sklade": 20},
        "margarin": {"price": 50, "mnozstvi": 250, "jednotky": "g", "na_sklade": 15},
        "dzem": {"price": 40, "mnozstvi": 400, "jednotky": "g", "na_sklade": 20},
        "med": {"price": 80, "mnozstvi": 300, "jednotky": "g", "na_sklade": 10},
        "tatarka": {"price": 30, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 15},
        "majoneza": {"price": 35, "mnozstvi": 0.2, "jednotky": "l", "na_sklade": 15},
        "olivy": {"price": 50, "mnozstvi": 150, "jednotky": "g", "na_sklade": 15},
        "nakladane_okurky": {"price": 40, "mnozstvi": 300, "jednotky": "g", "na_sklade": 20},
        "kapary": {"price": 60, "mnozstvi": 50, "jednotky": "g", "na_sklade": 10},
        "kysane_zeli": {"price": 30, "mnozstvi": 500, "jednotky": "g", "na_sklade": 15},
        "slanina_platky": {"price": 80, "mnozstvi": 200, "jednotky": "g", "na_sklade": 10},
        "mrazeny_hrasek": {"price": 30, "mnozstvi": 500, "jednotky": "g", "na_sklade": 20},
        "mrazeny_spenat": {"price": 25, "mnozstvi": 400, "jednotky": "g", "na_sklade": 15},
        "mrazeny_brokolice": {"price": 35, "mnozstvi": 300, "jednotky": "g", "na_sklade": 10},
        "mrazene_rybi_filety": {"price": 90, "mnozstvi": 600, "jednotky": "g", "na_sklade": 8},
        "mrazeny_kureci_prsa": {"price": 120, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 5},
        "mrazeny_kvetak": {"price": 40, "mnozstvi": 400, "jednotky": "g", "na_sklade": 10},
        "mrazeny_mrkev": {"price": 20, "mnozstvi": 300, "jednotky": "g", "na_sklade": 20},
        "mrazene_jahody": {"price": 60, "mnozstvi": 500, "jednotky": "g", "na_sklade": 15},
        "mrazene_maliny": {"price": 70, "mnozstvi": 400, "jednotky": "g", "na_sklade": 10},
        "mrazene_boruvky": {"price": 80, "mnozstvi": 300, "jednotky": "g", "na_sklade": 10},
        "mrazene_svestky": {"price": 50, "mnozstvi": 400, "jednotky": "g", "na_sklade": 10},
        "zmrzlina_vanilkova": {"price": 100, "mnozstvi": 1, "jednotky": "l", "na_sklade": 10},
        "zmrzlina_cokoladova": {"price": 80, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 15},
        "mrazene_lasagne": {"price": 120, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 5},
        "mrazena_pizza": {"price": 150, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 10},
        "mrazeny_bramborovy_hranolky": {"price": 50, "mnozstvi": 750, "jednotky": "g", "na_sklade": 20},
        "mrazene_pirohy": {"price": 60, "mnozstvi": 500, "jednotky": "g", "na_sklade": 15},
        "mrazene_maso": {"price": 200, "mnozstvi": 1000, "jednotky": "g", "na_sklade": 8},
        "mrazene_chleba": {"price": 25, "mnozstvi": 1, "jednotky": "ks", "na_sklade": 10},
        "mrazene_bulky": {"price": 40, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 10},
        "mrazene_rybi_prsty": {"price": 70, "mnozstvi": 300, "jednotky": "g", "na_sklade": 12},
        "mrazene_plody_mori": {"price": 120, "mnozstvi": 500, "jednotky": "g", "na_sklade": 8},
        "mrazene_gulase": {"price": 100, "mnozstvi": 2, "jednotky": "ks", "na_sklade": 5},
        "mrazene_ravioli": {"price": 60, "mnozstvi": 400, "jednotky": "g", "na_sklade": 10},
        "mrazene_susenky": {"price": 50, "mnozstvi": 250, "jednotky": "g", "na_sklade": 10},
        "voda": {"price": 10, "mnozstvi": 10, "jednotky": "l", "na_sklade": 50},
        "dzus_pomerancovy": {"price": 30, "mnozstvi": 2, "jednotky": "l", "na_sklade": 20},
        "dzus_jablecny": {"price": 25, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 15},
        "cola": {"price": 20, "mnozstvi": 1, "jednotky": "l", "na_sklade": 30},
        "sprite": {"price": 20, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 25},
        "tonic": {"price": 15, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 20},
        "pivo": {"price": 12, "mnozstvi": 6, "jednotky": "ks", "na_sklade": 50},
        "vino_bile": {"price": 100, "mnozstvi": 1, "jednotky": "l", "na_sklade": 10},
        "vino_cervene": {"price": 120, "mnozstvi": 1, "jednotky": "l", "na_sklade": 8},
        "whisky": {"price": 500, "mnozstvi": 0.7, "jednotky": "l", "na_sklade": 5},
        "rum": {"price": 300, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 10},
        "vodka": {"price": 200, "mnozstvi": 1, "jednotky": "l", "na_sklade": 15},
        "liker": {"price": 150, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 10},
        "kava": {"price": 80, "mnozstvi": 250, "jednotky": "g", "na_sklade": 30},
        "caj_cerny": {"price": 50, "mnozstvi": 100, "jednotky": "g", "na_sklade": 20},
        "caj_zeleny": {"price": 50, "mnozstvi": 100, "jednotky": "g", "na_sklade": 20},
        "energeticky_napoj": {"price": 40, "mnozstvi": 4, "jednotky": "ks", "na_sklade": 25},
        "mliko": {"price": 20, "mnozstvi": 2, "jednotky": "l", "na_sklade": 40},
        "smetana_do_kavy": {"price": 15, "mnozstvi": 0.25, "jednotky": "l", "na_sklade": 30},
        "mandlove_mleko": {"price": 35, "mnozstvi": 1, "jednotky": "l", "na_sklade": 20},
        "sojove_mleko": {"price": 30, "mnozstvi": 1, "jednotky": "l", "na_sklade": 20},
        "kakao": {"price": 25, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 15},
        "ledovy_caj": {"price": 20, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 25},
        "kokosova_voda": {"price": 30, "mnozstvi": 1, "jednotky": "l", "na_sklade": 15},
        "mineralka": {"price": 15, "mnozstvi": 1.5, "jednotky": "l", "na_sklade": 30},
        "perlive_vino": {"price": 150, "mnozstvi": 0.75, "jednotky": "l", "na_sklade": 10},
        "domaci_sirup": {"price": 50, "mnozstvi": 0.5, "jednotky": "l", "na_sklade": 20}
    },
    "open_from": (8, 0),
    "open_to": (20, 0),
    "distance": 2.5
}