# -*- coding: utf-8 -*-
"""
Znalostni system - Modul pro barvy (riedl_colors)
Autor: Martin Riedl
Email: marty69@students.zcu.cz
Datum: 08.12.2024
Verze: 1.0
"""

# Definice barev pro terminál
RED = "\033[91m"
GREEN = "\033[92m"
YELLOW = "\033[93m"
BLUE = "\033[94m"
CYAN = "\033[96m"
RESET = "\033[0m"

def print_colored(message, color="reset"):
    color_dict = {
        "green": GREEN,
        "yellow": YELLOW,
        "red": RED,
        "blue": BLUE,
        "cyan": CYAN,
        "reset": RESET
    }
    print(color_dict.get(color.lower(), RESET) + message + RESET)

def print_header(title):
    print(CYAN + "="*60 + RESET)
    print(CYAN + f"{title.center(60)}" + RESET)
    print(CYAN + "="*60 + RESET)

def print_subheader(title):
    print(CYAN + "-"*60 + RESET)
    print(CYAN + f"{title.center(60)}" + RESET)
    print(CYAN + "-"*60 + RESET)

def print_table(headers, rows):
    # Calculate column widths based on headers and rows
    col_widths = [len(header) for header in headers]
    for row in rows:
        for idx, item in enumerate(row):
            col_widths[idx] = max(col_widths[idx], len(str(item)))

    # Create format string
    format_str = " | ".join([f"{{:<{w}}}" for w in col_widths])

    # Print headers
    print(YELLOW + format_str.format(*headers) + RESET)
    # Print separator
    print(RED + "-+-".join(['-'*w for w in col_widths]) + RESET)
    # Print rows
    for row in rows:
        print(format_str.format(*row))
