# -*- coding: utf-8 -*-
"""
Znalostní systém pro vaření (hlavní spustitelný soubor) - riedl_main
Autor: Martin Riedl
Email: marty69@students.zcu.cz
Datum: 08.12.2024
Verze: 1.1

Popis:
Hlavní modul pro spouštění znalostního systému na vaření. Tento systém poskytuje:
- Správu inventáře ingrediencí (Inventory)
- Databázi receptů (Recipes)
- Inferenční engine pro doporučení receptů na základě dostupných surovin (InferenceEngine)
- Doporučování obchodů s ingrediencemi (StoreRecommender)
- Uživatelské rozhraní pro interakci s uživatelem (UserInterface)
- Doporučení a tutoriály k přípravě receptů (RecipeTutorials)

Použití:
Spuštění programu přes tento soubor inicializuje všechny potřebné moduly a spustí uživatelské rozhraní.

Moduly:
- riedl_inventory: Správa a sledování inventáře ingrediencí.
- riedl_recipes: Databáze a správa receptů.
- riedl_inference: Inferenční engine pro doporučení receptů.
- riedl_store: Doporučení obchodů pro nákup chybějících surovin.
- riedl_user_interface: Uživatelské rozhraní umožňující interakci s uživatelem.
- riedl_recipe_tutorials: Poskytování návodů a tipů na přípravu receptů.

Verze:
- 1.0: Základní funkčnost systému.
- 1.1: Přidán modul RecipeTutorials pro poskytování návodů na recepty.
"""

from modules.riedl_inventory import Inventory  # Správa inventáře ingrediencí
from modules.riedl_recipes import Recipes  # Databáze a správa receptů
from modules.riedl_inference import InferenceEngine  # Inferenční engine pro doporučení receptů
from modules.riedl_store import StoreRecommender  # Doporučení obchodů pro nákup surovin
from modules.riedl_user_interface import UserInterface  # Uživatelské rozhraní
from modules.riedl_recipe_tutorials import RecipeTutorials  # Doporučení dalších receptů

if __name__ == "__main__":
    # Inicializace modulů
    recipes = Recipes()  # Načtení a správa receptů
    inventory = Inventory()  # Načtení a správa inventáře ingrediencí
    recommender = StoreRecommender()  # Doporučování obchodů
    recipe_tutorials = RecipeTutorials()  # Poskytování návodů na recepty
    inference_engine = InferenceEngine(inventory, recipes, recipe_tutorials)  # Nastavení inferenčního enginu
    ui = UserInterface(inventory, inference_engine, recommender, recipe_tutorials, recipes)  # Nastavení uživatelského rozhraní

    # Spuštění hlavního menu uživatelského rozhraní
    ui.main_menu()

input("STOP")

