"""
Data Manager Module for Linear Equation Solver
Faiz Suleimanov
13.12.2024
version 1.0

This module handles the management of variables and equations for a linear equation solver.
It interacts with the KnowledgeBase to store, retrieve, and reset facts and equations.
"""

from sympy import parse_expr, Eq
from modules.knowledge_base import KnowledgeBase

class DataManager:
    """
    DataManager handles the management of variables and equations for the system.
    It interacts with the KnowledgeBase to store and retrieve equations and facts.
    """
    knowledge_base = None
    variables = None

    def __init__(self):
        """
        Initialize the DataManager with an empty knowledge base and variable list.
        """
        self.knowledge_base = KnowledgeBase()
        self.variables = []

    def set_variables(self, variable_names):
        """
        Set variables for equations.
        """
        try:
            self.variables = [parse_expr(name) for name in variable_names]
            return True
        except Exception as e:
            return str(e)

    def get_variables(self):
        """
        Get variables.
        """
        return self.variables

    def add_equation(self, equation_str):
        """
        Add equation to knowledge base.
        """
        try:
            left_str, right_str = equation_str.split('=')
            left = parse_expr(left_str)
            right = parse_expr(right_str)
            equation = Eq(left, right)
            self.knowledge_base.add_fact(equation)
            return True
        except Exception as e:
            return str(e)

    def get_knowledge_base(self):
        """
        Get knowledge base.
        """
        return self.knowledge_base

    def reset(self):
        """
        Reset the DataManager by clearing variables and the knowledge base.
        """
        self.variables = []
        self.knowledge_base.reset()
