"""
Solver Module for Linear Equation Solver
Faiz Suleimanov
13.12.2024
version 1.0

This module provides the `solve_gaus` function, which utilizes SymPy's `linsolve` to solve a
system of linear equations. It works with the knowledge base facts and variable list to find solutions.
"""

from sympy import linsolve


def solve_gaus(kb, variables):
    """
    Solve the system of linear equations using Gaussian elimination (via SymPy's linsolve).
    :param kb: The knowledge base instance containing the system of equations as facts.
    :param variables: The list of variables in the equations.
    """
    solutions = linsolve(kb.facts, *variables)

    if solutions:
        print("Solution:")
        for solution in solutions:
            for var, value in zip(variables, solution):
                print(f"{var} = {value}")
    else:
        print("System has not solutions")
