"""
**************************************************
Projekt: Semestralni prace - Hra NIM
Autor: Josef Zetek
E-Mail: jzetek24@students.zcu.cz
Datum: 16.12.2024
Popis: Program nacte pocet hromadek a pocet
       sirek v hromadkach. Nasledne se hraje duel
       uzivatele s pocitacem, kde ma uzivatel
       moznost zvolit si napovedu, ktera mu poradi
       optimalni tah.
**************************************************
"""


class GameState:
    """
    Reprezentuje stav hry
    """

    def __init__(self, piles):
        """
        Inicializuje hromadky
        :param piles: Hromadky zapalek
        """
        self.piles = piles

    def __eq__(self, other):
        """
        Funkce kontroluje, jestli jsou stavy stejne
        :param other: Jina instance GameState
        :return: True, pokud jsou instance stejne, jinak False
        """
        if not isinstance(other, GameState):
            return False

        # Vytvori hash mapy
        self_counts = {}
        other_counts = {}

        # Pocita vyskyt pro hodnotu v hromadkach teto instanci (napriklad hromadka obsahuje dve dvojky)
        for pile in self.piles:
            self_counts[pile] = self_counts.get(pile, 0) + 1

        # Pocita vyskyt pro hodnotu v hromadkach predane instanci
        for pile in other.piles:
            other_counts[pile] = other_counts.get(pile, 0) + 1

        # Porovnava dve hash mapy - tento zpusob je immuni vuci permutacim a je optimalni z hlediska vypocetni slozitosti
        return self_counts == other_counts

    def __hash__(self):
        """
        Funkce tvori hash pro dana data
        kvuli moznemu pouziti hashsetu
        :return: Vraci hash, ktery reprezentuje velikosti hromadek
        """
        return hash(tuple(sorted(self.piles)))

    def __str__(self):
        """
        Textova reprezentace stavu hry
        :return: Textova reprezentace stavu hry
        """

        text = f"Stav hry - hromadky:"

        for i, pile in enumerate(self.piles):
            text += f"\nHromadka {i + 1}: {pile}"

        return text + "\n"
