"""
**************************************************
Projekt: Semestralni prace - Hra NIM
Autor: Josef Zetek
E-Mail: jzetek24@students.zcu.cz
Datum: 16.12.2024
Popis: Program nacte pocet hromadek a pocet
       sirek v hromadkach. Nasledne se hraje duel
       uzivatele s pocitacem, kde ma uzivatel
       moznost zvolit si napovedu, ktera mu poradi
       optimalni tah.
**************************************************
"""

from typing import Dict
from Data.GameState import GameState


class Knowledge:
    """
    Trida reprezentuje znalosti o hre
    """

    def __init__(self):
        """
        Inicializuje znalosti - ktere stavy uz byly zpracovany a jejich vysledky
        """
        # Use a set for fast lookup and avoiding duplicates
        self.knowledge: Dict[GameState, int] = {}

    def add_state(self, state: GameState, result: int, is_maximizing: bool):
        """
        Prida stav do znalosti - pokud je znamy vysledek, ulozi se
        :param state: Stav hry
        :param result: Vysledek hry
        :param is_maximizing: Priznak, jestli je vysledek pro maximalizujiciho hrace
        """

        # Inverze vysledku tak, aby stav odpovidal maximalizujicimu hraci
        if not is_maximizing:
            result = -result

        # Ulozeni stavu a jeho vysledku
        self.knowledge[state] = result

    def contains_state(self, state: GameState):
        """
        Metoda kontroluje, jesli byl stav jiz zpracovan
        :param state: Stav hry
        :return: True, pokud byl stav zpracovan, jinak False
        """
        return state in self.knowledge

    def get_result(self, state: GameState, is_maximizing: bool):
        """
        Vraci vysledek pro dany stav
        :param state: Stav hry
        :param is_maximizing: Priznak, jestli se ma vysledek vyhodnotit pro maximalizujiciho hrace
        :return: Vysledek pro dany stav
        """

        if not is_maximizing:
            return -self.knowledge[state]

        return self.knowledge[state]
